@@ -64,12 +64,12 @@ EXEC_SERVER_CACERT = None  # SSL CA certificate
 EXEC_SERVER_DHPARAM = None # Diffie-Hellman param
 EXEC_SERVER_CIPHERS = None # SSL ciphers to use/exclude
 PIDFILE = '/var/run/exec-proxy.pid'
-PROXY_LOG = '/var/log/mw-proxy/exec-proxy.log'
+PROXY_LOG = '/var/log/exec-proxy/exec-proxy.log'
 HEADER_TIMEOUT = 20
 
 FORWARD_PORT = 8000
-RUN_UID = 'www-data'
-RUN_GID = 'www-data'
+RUN_UID = 'hz-exec-proxy'
+RUN_GID = 'hz-exec-proxy'
 
 from hubzero.mw.constants import MYSQL_CONN_ATTEMPTS, EXEC_CONFIG_FILE
 from hubzero.mw.constants import MYSQL_CONN_ATTEMPTS
@@ -625,6 +625,9 @@ def termination_handler(signo,extra):
 #==============================================================================
 def main():
   global verbosity
+  import syslog
+  # write to syslog until we change uid
+  syslog.syslog("exec-proxy starting up")
   # Create the listening socket before backgrounding or writing the pidfile.
   try:
     ls = create_listener(EXEC_LISTEN_HOST, EXEC_LISTEN_PORT)
@@ -655,11 +658,7 @@ def main():
     daemonize()
 
   write_pidfile(PIDFILE)
-
-  setup_log(PROXY_LOG, None)
-  log('Starting up')
-  if verbosity > 0:
-    log('Verbosity level %d' % verbosity)
+  syslog.syslog("exec-proxy switching to user %s" % RUN_GID)
 
   try:
     import grp
@@ -673,6 +672,12 @@ def main():
   except:
     fatal('Unable to set uid to %s' % RUN_UID)
 
+  # start writing to log only after changing uid, to avoid writing as root in non-root owned directory
+  setup_log(PROXY_LOG, None)
+  log('Starting up')
+  if verbosity > 0:
+    log('Verbosity level %d' % verbosity)
+
   # Invoke the handler loop.  Catch and print any unusual exceptions.
   try:
     main_loop(ls)
